@@ -25,3 +25,13 @@ fn last_modified_is_accurate() {
 
   assert_eq!(index_file.metadata.last_modified(), Some(expected_datetime_utc));
 }
+
+#[test]
+fn create_is_accurate() {
+  let index_file: EmbeddedFile = Asset::get("index.html").expect("index.html exists");
+
+  let metadata = fs::metadata(format!("{}/examples/public/index.html", env!("CARGO_MANIFEST_DIR"))).unwrap();
+  let expected_datetime_utc = metadata.created().unwrap().duration_since(SystemTime::UNIX_EPOCH).unwrap().as_secs();
+
+  assert_eq!(index_file.metadata.created(), Some(expected_datetime_utc));
+}
